<?php

/**
 * The CSS AutoLoader core plugin class
 */

 
// If this file is called directly, abort
if ( ! defined( 'WPINC' ) ) {
	die;
}


/**
 * The core plugin class
 */
if ( !class_exists( 'PP_Css_Autoloader' ) ) { 

  class PP_Css_Autoloader {
    
    private $_file;
    private $_autoloaddir;
    public $plugin_name;
    public $plugin_slug;
    public $version;
    public $media;
    private $wp_url;
    private $my_url;
    private $admin_handle;

    
    /**
	   * here we go
     */
    public function __construct( $file ) {
      $this->_file = $file;
      $this->_autoloaddir = 'cssautoload';
      $this->plugin_name = 'CSS AutoLoader';
      $this->plugin_slug = 'css-autoloader';
      $this->version = '2.3';
      $this->init();
    }
    
    
    /**
     * do plugin init 
     */
    private function init() {
      // allowed media types
      $this->media = array( '' => 'all', '/all' => 'all', '/braille' => 'braille', '/embossed' => 'embossed', '/handheld' => 'handheld', '/print' => 'print', '/projection' => 'projection', '/screen' => 'screen', '/speech' => 'speech', '/tty' => 'tty', '/tv' => 'tv' );
      
      $this->wp_url = 'https://wordpress.org/plugins/' . $this->plugin_slug;
      $this->my_url = 'https://petersplugins.com/free-wordpress-plugins/' . $this->plugin_slug;
      
      add_action( 'wp_enqueue_scripts', array( $this, 'cssautoloader' ), 999 );
      add_action( 'init', array( $this, 'add_text_domain' ) );
      add_action( 'admin_menu', array( $this, 'adminmenu' ) );
      add_action( 'admin_head', array( $this, 'admin_css' ) );
      add_filter( 'plugin_action_links_' . plugin_basename( $this->_file ), array( $this, 'add_links' ) ); 
      
    }

    
    /**
     * autoload CSS files on frontend
     */
    function cssautoloader() {
      foreach ( $this->getAllFiles() as $file ) {
        wp_enqueue_style( 'cssautoloader-' . md5( $file['name'] ), $file['url'], array(), $file['version'], $file['media'] );
      }
    }

    
    /**
     * init backend
     */
    function adminmenu() {
      $this->admin_handle = add_management_page( 'CSS AutoLoader', 'CSS AutoLoader', 'activate_plugins', 'cssautoloader', array( $this, 'showadmin' ) );
    }
    
    
    /**
     * add text domain
     */
    function add_text_domain() {  
      load_plugin_textdomain( 'css-autoloader' );
    }


    /**
     * get an array of possible directories
     */
    function getDirs() {
      $possibledirs = array();
      $possibledirs['general'] = array( 'dir' => $this->mk_path( WP_CONTENT_DIR ), 'url' => $this->mk_url( content_url() ) );
      $possibledirs['theme'] = array( 'dir' => $this->mk_path( get_template_directory() ), 'url' => $this->mk_path( get_template_directory_uri() ) );
      if ( is_child_theme() ) {
        $possibledirs['childtheme'] =  array( 'dir' => $this->mk_path( get_stylesheet_directory() ), 'url' => $this->mk_path( get_stylesheet_directory_uri() ) );
      } else {
        $possibledirs['childtheme'] = false;
      }
      return $possibledirs;
    }
    
    
    /**
     * create path name
     */
    private function mk_path( $dir ) {
      
      $path = $dir;
      
      if ( $path != '' ) {
        
        $path = trailingslashit( $dir ) . $this->_autoloaddir;
        
      }
      
      return $path;
      
    }
    
    
    /**
     * create url path name
     */
    private function mk_url( $dir ) {
      
      $path = $dir;
      
      if ( $path != '' ) {
        
        $path = trailingslashit( $dir ) . $this->_autoloaddir;
        
      }
      
      return $path;
      
    }

    
    /**
     * get an sorted array of all *.css files in all possible loactions 
     */
    function getAllFiles() {
      $possibledirs = $this->getDirs();
      $files = array();
      foreach ( $possibledirs as $pdir ) {
        if ( $pdir ) {
          if ( is_dir( $pdir['dir'] ) ) {
            foreach ( $this->media as $mdir => $media ) {
              $curdir = $pdir['dir'] . $mdir;
              if ( is_dir( $curdir ) ) {
                foreach ( scandir( $curdir ) as $file ) {
                  if ( $file !== '.' && $file !== '..' && !is_dir( trailingslashit( $curdir ) . $file ) && substr( $file, 0, 1 ) != '_' && '.css' == strtolower( substr( $file, -4 ) ) ) {
                    $files[] = array( 'name' => trailingslashit( $curdir ) . $file, 'url' => $pdir['url'] . trailingslashit( $mdir ) . $file, 'file' => $file, 'media' => $media, 'version' =>  date( 'U', filemtime( trailingslashit( $curdir ) . $file ) ) );
                  }
                }
              }
            }
          }
        }
      }
      return $files;
    }


    /**
     * show admin page
     */
    function showadmin() {
      if ( !current_user_can( 'activate_plugins' ) )  {
        wp_die( ___( 'You do not have sufficient permissions to access this page.' ) );
      }
      ?>
      <div class="wrap">
        <h1 id="pp-plugin-info-css-autoloader"><?php echo $this->plugin_name; ?> <?php _e( 'Settings', 'css-autoloader' ); ?><span><a class="dashicons dashicons-star-filled" href="https://wordpress.org/support/plugin/<?php echo $this->plugin_slug; ?>/reviews/" title="<?php _e( 'Please rate plugin', 'css-autoloader' ); ?>"></a> <a class="dashicons dashicons-wordpress" href="<?php echo $this->wp_url; ?>/" title="<?php _e( 'wordpress.org plugin directory', 'css-autoloader' ); ?>"></a> <a class="dashicons dashicons-admin-home" href="https://petersplugins.com/" title="<?php _e( 'Author homepage', 'css-autoloader' );?>"></a> <a class="dashicons dashicons-googleplus" href="https://plus.google.com/+petersplugins/" title="<?php _e( 'Authors Google+ Page', 'css-autoloader' ); ?>"></a> <a class="dashicons dashicons-facebook-alt" href="https://www.facebook.com/petersplugins/" title="<?php _e( 'Authors facebook Page', 'css-autoloader' ); ?>"></a> <a class="dashicons dashicons-editor-help" href="https://wordpress.org/support/plugin/<?php echo $this->plugin_slug; ?>/" title="<?php _e( 'Support', 'css-autoloader'); ?>"></a> <a class="dashicons dashicons-admin-comments" href="https://petersplugins.com/contact/" title="<?php _e( 'Contact Author', 'css-autoloader' ); ?>"></a></span></h1>
        <?php settings_errors(); ?>

        <div class="postbox">
          <div class="inside">
            <p><strong><?php _e( 'Currently loaded CSS files (in that order)', 'css-autoloader'); ?></strong></p>
            <?php $this->showcurrent(); ?>
            
          </div>
        </div>
       
        <?php $possibledirs = $this->getDirs(); ?>
        <div class="postbox">
          <div class="inside">
            <p><strong><?php _e( 'Possible paths to store your CSS files', 'css-autoloader'); ?></strong></p>
            <p><strong><?php _e( 'General Directory', 'css-autoloader'); ?></strong></p>
            <p><?php _e( 'Current Path', 'css-autoloader' ); ?>: <code><?php echo $possibledirs['general']['dir']; ?></code></p>
            <p><strong><?php _e( 'Theme Directory', 'css-autoloader'); ?></strong></p>
            <p><?php _e( 'Current Path', 'css-autoloader' ); ?>: <code><?php echo $possibledirs['theme']['dir']; ?></code></p>
            <p><strong><?php _e( 'Child Theme Directory', 'css-autoloader'); ?></strong></p>
            <p><?php 
              if ( $possibledirs['childtheme'] ) {
                echo __( 'Current Path', 'css-autoloader' ) . ': <code>' . $possibledirs['childtheme']['dir'] . '</code>';
              } else {
                _e( 'You are not using a Child Theme', 'css-autoloader' );
              }
            ?></p>
          </div>
        </div>
        
      </div>
      <?php
    }

    
    /**
     * list currently loaded css files on admin page
     */
    function showcurrent() {
      $filesarray = $this->getAllFiles();  
      if ( empty( $filesarray ) ) {
        echo '<p>' . __( 'no files loaded currently', 'css-autoloader' ) . '</p>';
      } else {
        echo '<table style="width: 100%"><tbody>';
        foreach ( $filesarray as $file ) {
          echo '<tr><td colspan="3"><strong><a href="' . $file['url'] . '">' . $file['url'] . '</a></strong></td></tr><tr><td style="width: 20px">&nbsp;</td><td>' . __( 'File', 'css-autoloader' ) . '</td><td><code>' . $file['name'] . '</code></td></tr><tr><td style="width: 20px">&nbsp;</td><td>' . __( 'Media', 'css-autoloader' ) . '</td><td><strong>' . $file['media'] .  '</strong></td></tr>';
        }
        echo '</tbody></table>';
      }
    }
    
    
    /**
     * add links to plugins table
     */
    function add_links( $links ) {
      return array_merge( $links, array( '<a href="' . admin_url( 'tools.php?page=cssautoloader' ) . '" title="' . __( 'Show currently loaded files', 'css-autoloader' ) . '">' . __( 'Show currently loaded files', 'css-autoloader' ) . '</a>', '<a href="https://wordpress.org/support/plugin/' . $this->plugin_slug . '/reviews/" title="' . __( 'Please rate plugin', 'css-autoloader' ) . '">' . __( 'Please rate plugin', 'css-autoloader' ) . '</a>' ) );
    }
    
    
    /**
     * add admin css
     */
    function admin_css() {
      if ( get_current_screen()->id == $this->admin_handle ) {
        echo '<style type="text/css">#pp-plugin-info-css-autoloader{ min-height: 48px; line-height: 48px; vertical-align: middle; padding-left: 60px; background-image: url(' . plugins_url( 'assets/pluginicon.png', $this->_file ) .'); background-repeat: no-repeat; background-position: left center;}#pp-plugin-info-css-autoloader span{float: right; padding-left: 50px;}#pp-plugin-info-css-autoloader .dashicons{ vertical-align: middle; }#pp-plugin-info-css-autoloader + .postbox{margin-top: 20px}</style>';
      }
    }
  }
  
}

?>